import requests


class RequestsApi:
    def __init__(self, base_url, **kwargs):
        self.base_url = base_url
        self.session = requests.Session()
        for arg in kwargs:
            if isinstance(kwargs[arg], dict):
                kwargs[arg] = self.__deep_merge(getattr(self.session, arg), kwargs[arg])
            setattr(self.session, arg, kwargs[arg])

    def get(self, url, **kwargs):
        return self.session.get(self.base_url + url, **kwargs)

    def post(self, url, **kwargs):
        return self.session.post(self.base_url + url, **kwargs)

    @staticmethod
    def __deep_merge(source, destination):
        for key, value in source.items():
            if isinstance(value, dict):
                node = destination.setdefault(key, {})
                RequestsApi.__deep_merge(value, node)
            else:
                destination[key] = value
        return destination


baseurl = RequestsApi("https://omeku.glitch.me/api/v1")


def get(endpoint):
    r = baseurl.get(endpoint)
    return r.json()



import urllib

from . import http, dict, errors

noresponse = "Couldn't contact the API right now..."


def img(target: str):
    possible = [
        'pat', 'kiss', 'neko', 'hug', 'lick'
    ]

    if target is None:
        raise errors.EmptyArgument("You have to at least define an argument in string format\nArguments: {}".format(possible))

    if target.lower() not in possible:
        raise errors.InvalidArgument("You haven't added any valid arguments\nArguments: {}".format(possible))

    try:
        if target.lower() == "neko":
            r = http.get("/neko")
        else:
            r = http.get("/" + target.lower())
    except Exception as e:
        raise errors.NothingFound(noresponse)

    return r["url"]



class OmekuException(Exception):
    """ Base exception class for omeku.py """

    pass


class NothingFound(OmekuException):
    """ The API didn't return anything """

    pass


class EmptyArgument(OmekuException):
    """ When no target is defined """

    pass


class InvalidArgument(OmekuException):
    """ Invalid argument within the category """

    pass



import re

from setuptools import setup


version = ''
with open('omeku/__init__.py') as f:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', f.read(), re.MULTILINE).group(1)


requirements = []
with open('requirements.txt') as f:
    requirements = f.read().splitlines()


if not version:
    raise RuntimeError('version is not set')


setup(
    name='omeku.py',
    author='jdev2005',
    url='https://github.com/jdev2005/omeku.py',
    version=version,
    packages=['omeku'],
    license='MIT',
    description='A Python module that uses Omeku API',
    include_package_data=True,
    install_requires=requirements
)
